// toShare member.js
'use strict';
// uses rest

const sectionMember = document.querySelector('section.member');
const buttonNew = sectionMember.querySelector('button.new');
const tableMember = sectionMember.querySelector('table');
const tbodyMember = sectionMember.querySelector('tbody');
const trTemplateMember = tbodyMember.firstElementChild.cloneNode(true);

const divEditLayer = document.querySelector('div.edit-layer');
const tableEdit = divEditLayer.querySelector('table');
const tbodyEdit = divEditLayer.querySelector('tbody');
const trTemplateEdit = tbodyEdit.firstElementChild.cloneNode(true);
const buttonCancel = divEditLayer.querySelector('button.cancel');
const buttonAdd = divEditLayer.querySelector('button.add');
const buttonDel = divEditLayer.querySelector('button.delete');

const boardId = Number(document.location.hash.substring(1));
let countAdd = 0;
let memoMouseOutside = false;

async function initializaPage(){
	try{
		tbodyMember.innerHTML = '';
		atsConfiguration.reflection();
		await atsInoutboards.restGet(WITHDISABLED);
		await atsUsersTable.restGet(USER_ID_ALL, WITHDISABLED);
		const atsInoutboard = atsInoutboards.findField('board_id',boardId);
		const h1Tag = document.querySelector('h1');
		h1Tag.innerHTML = '&#x25A0; ';
		h1Tag.innerText +=  atsInoutboard.board_name + ' - 構成員';
		document.title = h1Tag.innerText + ' - toShare'

		updateMemberList();

		divEditLayer.addEventListener('mousedown', onOutsideClick);
		divEditLayer.addEventListener('mouseup', onOutsideClick);
		buttonNew.addEventListener('click', onNewEdit);
		buttonCancel.addEventListener('click', onCancel);

		buttonAdd.addEventListener('click', onExecute);
		buttonDel.addEventListener('click', onExecute);
	}catch(e){
		location.href=location.origin;
	}
}

async function updateMemberList(){
	await atsAttendance.restGet(USER_ID_ALL, WITHDISABLED);
	tbodyMember.innerHTML = '';
	for(const atsMember of atsAttendance.data){
		if(atsMember.board_id == boardId){
			const atsUser = atsUsersTable.findField('user_id', atsMember.user_id);
			const userTr = trTemplateMember.cloneNode(true);
			const td = userTr.querySelectorAll("td");
			userTr.dataset.userId = atsUser.user_id;
			if(atsUser.disable){userTr.classList.add('disable');}
			td[0].innerText = atsUser.user_account;
			td[1].innerText = atsUser.user_name;
			td[2].innerText = atsUser.user_desc;
			td[3].innerText = atsUser.user_series;
			td[4].textContent = (atsUser.disable)? '非表示' : '';
			userTr.addEventListener('click', onTrMemberClick);
			tbodyMember.appendChild(userTr);
		}
	}
	updateUserAttendance()
}

function updateEditList(userId){
	countAdd = 0;
	tbodyEdit.innerHTML = '';
	for(const atsUser of atsUsersTable.data){
		if((userId == undefined) || (atsUser.user_id == userId)){
			const atsMember = atsAttendance.findField('user_id', atsUser.user_id);
			const isMember = atsMember ? atsMember.board_id == boardId : false;
			if(!atsUser.disable || isMember){
				const userTr = trTemplateEdit.cloneNode(true);
				const td = userTr.querySelectorAll("td");
				userTr.dataset.userId = atsUser.user_id;
				if(atsMember){
					td[0].innerText = atsInoutboards.findField('board_id', atsMember.board_id).board_name;
					if(userId != undefined)	userTr.classList.add('individual')
					else if(isMember)		userTr.classList.add('selected');
				}else{
					td[0].innerText = '';
				}
				td[1].innerText = atsUser.user_account;
				td[2].innerText = atsUser.user_name;
				td[3].innerText = atsUser.user_desc;
				td[4].innerText = atsUser.user_series;
				td[5].textContent = (atsUser.disable)? '非表示' : '';
				userTr.addEventListener('click', onTrEditClick);
				tbodyEdit.appendChild(userTr);
			}
		}
	}
}

function onNewEdit(){
	divEditLayer.style.display = 'flex';
	updateEditList();
	buttonAdd.disabled = true;
	buttonDel.disabled = true;
}

function onTrMemberClick(event){
	event.currentTarget.classList.add('current');
	updateEditList(Number(event.currentTarget.dataset.userId));
	divEditLayer.style.display = 'flex';

	buttonAdd.disabled = true;
	buttonDel.disabled = false;
}

function onOutsideClick(event){
	if(event.currentTarget===event.target){
		if(memoMouseOutside){
			onCancel();
		}else{
			 memoMouseOutside = true;
		}
	}else{
		memoMouseOutside = false;
	}
}
function onTrEditClick(event){
	if((!event.currentTarget.classList.contains('selected'))
	&& (!event.currentTarget.classList.contains('individual'))){
		if(event.currentTarget.classList.contains('select')){
			event.currentTarget.classList.remove('select');
			countAdd -= 1;
		}else{
			event.currentTarget.classList.add('select');
			countAdd += 1;
		}
		buttonAdd.disabled = countAdd==0;
	}
}
function getSelectUserIds(){
	const userIds = [];
	for(const userTr of tbodyEdit.querySelectorAll('tr.select')){
		userIds.push(Number(userTr.dataset.userId));
	}
	return userIds;
}
function onCancel(){
	for(const tbodyTr of tbodyMember.querySelectorAll('tr')){
		if(tbodyTr.classList.contains('current')){tbodyTr.classList.remove('current');}
	}
	divEditLayer.style.display = 'none';
}
function onMemberModified(){
	if(Number(inputUserId.value)===0){
		buttonAdd.disabled = false;
		buttonDel.disabled = true;
	}else{
		buttonAdd.disabled = true;
		buttonDel.disabled = false;
	}
}
async function onExecute(event){
	switch(event.target){
		case buttonAdd:{
			try{
				await atsAttendance.restPost(
					getSelectUserIds(),
					boardId
				)
			}catch(e){confirm(e.message);}
			break;
		}
		case buttonDel:{
			try{
				await atsAttendance.restDelete(
					Number(tbodyEdit.firstChild.dataset.userId),
					boardId
				)
			}catch(e){confirm(e.message);}
			break;
		}
		default: confirm('onExecute tagert unknown');
	}
	divEditLayer.style.display = 'none';
	updateMemberList();
}

initializaPage();
